/*

  Tonde Buurin HKG Sound Scheme Installation Script

  This REXX script will add a new sound scheme, "Tonde Buurin HKG",
  based on sound clips taken from the Cantonese version of Tonde Buurin.

  There are several events for which a sound file is not provided. It is
  recommended that you un-assign all sound files from all sound events
  before running the script and selecting the new scheme.

*/
say 'Tonde Buurin Sound Scheme Revision 3 - Cantonese edition'
say '(c) 1997-1999 Keith''s Tonde Buurin Page'
say
say 'Installation Helper V1.00.002 (c) 1997-1999 Keith Hui. All rights reserved.'
say
say 'Downloaded from Keith''s Tonde Buurin Page'
say 'http://www.geocities.com/Tokyo/6707'
say
say "Comments and questions should be sent to kokubu-karin@geocities.com"
say
say "This helper program is designed to assist in installing the"
say "Tonde Buurin Sound Scheme on a computer running OS/2"
say "as its operating system. For further instructions see BUUSND.TXT."
say
say "This helper is for this revision and edition only. Do not carry"
say "it forward to next revision or use it in other editions."
say


SND_Warning         = 'BUUUUU.WAV'
SND_Information     = 'BUBU.WAV'
SND_Error           = 'CRASH.WAV'
SND_Open_window     = 'CLICK.WAV'
SND_Close_window    = 'HEHEC.WAV'
SND_Begin_drag      = ''
SND_End_drag        = ''
SND_System_startup  = 'MAKEUPC.WAV'
SND_System_shutdown = 'BYEBUUC.WAV'
SND_Shred           = 'HOHOHO.WAV'
SND_Lockup          = 'HEHEC.WAV'
SND_Alarm           = 'TONALARM.WAV'
SND_Printer_error   = 'WAWAC.WAV'

SND_SchemeTitle     = 'Tonde Buurin (HKG)'
SND_SchemeName      = 'PM_SOUNDS_BUURIN_HKG'
/* - End customizable portion - */

call RxFuncAdd 'SysLoadFuncs', 'Rexxutil', 'SysLoadFuncs'
call SysLoadFuncs

os2ver = SysOS2Ver()

if os2ver = '2.40' then
do
    say "OS/2 Warp 4"
    newwarp = 1
    SYSTEMINI = 'SYSTEM' /* System INI */
end
else
do
    badver = 0
    if substr(os2ver,1,1) = '1' then badver = 1
    if substr(os2ver,1,3) = '2.0' then badver=1
    if substr(os2ver,1,3) = '2.1' then say 'OS/2 Version 2.1x'
    if substr(os2ver,1,3) = '2.3' then say 'OS/2 Warp 3'
    if badver = 1 then
    do
        say 'Unsupported OS/2 version'
        exit
    end

    newwarp = 0
    fspec1 = SysSearchPath('PATH','MMPM.INI')
    fspec2 = SysSearchPath('PATH','MMPM2.INI')
    pathsp1 = lastpos('\', fspec1)
    pathsp2 = lastpos('\', fspec2)
    cmpa = substr(fspec1, 1, pathsp1)
    cmpb = substr(fspec2, 1, pathsp2)
    if (cmpa = cmpb) then
        systemini = fspec1
    else
        systemini = ''
end

say
if systemini = '' then
do
    say 'OS/2 multimedia support (MMPM/2) not installed.'
    exit
end

/* Add scheme title */
if newwarp = 1 then
do
    call SysIni SYSTEMINI,'PM_SOUND_SCHEMES_LIST',SND_SchemeTitle || X2C(0), SND_SchemeName || X2C(0)

    /* Add the 13 sound events */
    call AddSchemeEntry 0, SND_Warning
    call AddSchemeEntry 1, SND_Information
    call AddSchemeEntry 2, SND_Error
    call AddSchemeEntry 3, SND_Open_window
    call AddSchemeEntry 4, SND_Close_window
    call AddSchemeEntry 5, SND_Begin_drag
    call AddSchemeEntry 6, SND_End_drag
    call AddSchemeEntry 7, SND_System_startup
    call AddSchemeEntry 8, SND_System_shutdown
    call AddSchemeEntry 9, SND_Shred
    call AddSchemeEntry 10, SND_Lockup
    call AddSchemeEntry 11, SND_Alarm
    call AddSchemeEntry 12, SND_Printer_error

    say 'Scheme installation complete. For instructions in changing sound'
    say 'schemes, see BUUSND.TXT.'
end
else
do

    /* Add the 13 sound events */
    call AddSoundEntry 0, SND_Warning
    call AddSoundEntry 1, SND_Information
    call AddSoundEntry 2, SND_Error
    call AddSoundEntry 3, SND_Open_window
    call AddSoundEntry 4, SND_Close_window
    call AddSoundEntry 5, SND_Begin_drag
    call AddSoundEntry 6, SND_End_drag
    call AddSoundEntry 7, SND_System_startup
    call AddSoundEntry 8, SND_System_shutdown
    call AddSoundEntry 9, SND_Shred
    call AddSoundEntry 10, SND_Lockup
    call AddSoundEntry 11, SND_Alarm
    call AddSoundEntry 12, SND_Printer_error

    say 'Sound installation complete.'
end
exit

CompleteFileName: Procedure
    shortfile = arg(1)
    if shortfile = '' then return ''
    else
    do
        longfile = directory() || '\' || shortfile
        return longfile
    end
    return

AddSchemeEntry: Procedure expose SYSTEMINI SND_SchemeName
    truefilename = CompleteFileName(arg(2))
    call SysIni SYSTEMINI,SND_SchemeName,arg(1),truefilename || X2C(0)
    return

AddSoundEntry: Procedure expose SYSTEMINI
    truefilename = CompleteFileName(arg(2))
    inient = SysIni(SYSTEMINI,'MMPM2_AlarmSounds',arg(1))
    if inient = "ERROR:" then inient = ''
    pthend = pos('#',inient)
    if pthend = 0 then
        newinient = inient
    else
        newinient = truefilename || substr(inient,pthend)
    call SysIni SYSTEMINI,'MMPM2_AlarmSounds',arg(1),newinient
    return
